package com.ruoyi.oa.mapper;

import java.util.List;
import com.ruoyi.oa.domain.CmcDeviceHandover;

/**
 * cmc设备移交Mapper接口
 * 
 * @author cmc
 * @date 2024-05-21
 */
public interface CmcDeviceHandoverMapper 
{
    /**
     * 查询cmc设备移交
     * 
     * @param deviceHandoverId cmc设备移交主键
     * @return cmc设备移交
     */
    public CmcDeviceHandover selectCmcDeviceHandoverByDeviceHandoverId(Integer deviceHandoverId);

    /**
     * 查询cmc设备移交列表
     * 
     * @param cmcDeviceHandover cmc设备移交
     * @return cmc设备移交集合
     */
    public List<CmcDeviceHandover> selectCmcDeviceHandoverList(CmcDeviceHandover cmcDeviceHandover);

    /**
     * 新增cmc设备移交
     * 
     * @param cmcDeviceHandover cmc设备移交
     * @return 结果
     */
    public int insertCmcDeviceHandover(CmcDeviceHandover cmcDeviceHandover);

    /**
     * 修改cmc设备移交
     * 
     * @param cmcDeviceHandover cmc设备移交
     * @return 结果
     */
    public int updateCmcDeviceHandover(CmcDeviceHandover cmcDeviceHandover);

    /**
     * 删除cmc设备移交
     * 
     * @param deviceHandoverId cmc设备移交主键
     * @return 结果
     */
    public int deleteCmcDeviceHandoverByDeviceHandoverId(Integer deviceHandoverId);

    /**
     * 批量删除cmc设备移交
     * 
     * @param deviceHandoverIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteCmcDeviceHandoverByDeviceHandoverIds(Integer[] deviceHandoverIds);
}
